@@ -25,6 +25,8 @@ from .taxes.clients import TaxClient
 from .wallets.clients import WalletClient, WalletTransactionClient
 from .webhooks.clients import WebhookClient
 from .webhook_endpoints.clients import WebhookEndpointClient
+from .activity_logs.clients import ActivityLogClient
+from .api_logs.clients import ApiLogClient
 
 try:
     from typing import Final
@@ -164,3 +166,11 @@ class Client:
     @callable_cached_property
     def webhook_endpoints(self) -> WebhookEndpointClient:
         return WebhookEndpointClient(self.base_api_url, self.api_key)
+
+    @callable_cached_property
+    def activity_logs(self) -> ActivityLogClient:
+        return ActivityLogClient(self.base_api_url, self.api_key)
+
+    @callable_cached_property
+    def api_logs(self) -> ApiLogClient:
+        return ApiLogClient(self.base_api_url, self.api_key)
